References
==============

.. [Hunter2007] John D. Hunter. Matplotlib: A 2D Graphics Environment, Computing in Science & Engineering, 9, 90-95 (2007), DOI:10.1109/MCSE.2007.55

.. [McKinney2013] W. McKinney, (2013) Python for Data Analysis: Data Wrangling with Pandas, NumPy, and IPython

.. [Ronacher2008] Armin Ronacher, (2008), Template Designer Documentation, http://jinja.pocoo.org/docs/dev/templates/ accessed July 1, 2016.

.. [Stein2016] J.S. Stein, W.F. Holmgren, J. Forbess, and C.W. Hansen, PVLIB: Open Source Photovoltaic Performance Modeling Functions for Matlab and Python, in 43rd Photovoltaic Specialists Conference, 2016

.. [vanderWalt2011] Stefan van der Walt, S. Chris Colbert and Gael Varoquaux. The NumPy Array: A Structure for Efficient Numerical Computation, Computing in Science & Engineering, 13, 22-30 (2011), DOI:10.1109/MCSE.2011.37
